@@ -6,13 +6,15 @@ import json
 from pathlib import Path
 
 from .config import Config
-from .parser import PARSER_DICT
+from .parser import (PARSER_DICT,
+                     parser_decorator,
+                     BeautifulSoup)
 from .config_cmd import ConfigCmd
 from .main import FindHome
 
 import traceback
 
-__all__ = ['main_loop', 'edit_config']
+__all__ = ['main_loop', 'test_urls', 'BeautifulSoup', 'edit_config', 'parser_decorator', 'PARSER_DICT']
 
 
 def excepthook(excType, excValue, tracebackobj):
@@ -42,6 +44,15 @@ def main_loop(config_path: str = None, *, delay: int = None):
         fh.check()
 
 
+def test_urls():
+    for k, func in PARSER_DICT.items():
+        try:
+            print(k, ', url: ', func.url)
+            print('Result: ', func())
+        except Exception as err:
+            print(f'Exception occurred for {k}', err)
+
+
 def edit_config():
     setup_logging()
     sys.excepthook = excepthook
