@@ -36,16 +36,16 @@ class FindHome(object):
                 continue
             if self._info_dict[k] != new_info:
                 self.log.info(f'Info has been changed to {new_info}.')
-                self.broadcast(new_info)
+                self.broadcast(_broadcast_message(new_info, func.url))
                 self._info_dict[k] = new_info
             else:
                 self.log.info(f'Same info from {k}: {new_info}.')
 
-    def broadcast(self, msg: str):
+    def broadcast(self, msg: str, subject: str = 'Accommodation'):
         self.log.info(f'Broadcasting message: {msg}.')
         try:
             send_message(msg, self.config.server_mail, self.config.password, self.config.recipients,
-                         self.config.port, self.config.hostname)
+                         self.config.port, self.config.hostname, subject=subject)
             self.log.info('Message was sent.')
         except Exception as err:
             self.log.exception(err)
@@ -59,3 +59,11 @@ class FindHome(object):
             self.log.info('Message was sent.')
         except Exception as err:
             self.log.exception(err)
+
+
+def _broadcast_message(new_info: str, url: str) -> str:
+    return f"""New offer: {new_info}!
+    
+    Go to this link:
+    {url}.
+    """
