@@ -10,10 +10,10 @@ from bs4 import BeautifulSoup
 
 logger = logging.getLogger(__name__)
 
-__all__ = ['get_soup', 'PARSER_DICT', 'parser_decorator']
+__all__ = ['get_soup', 'PARSER_DICT', 'parser_decorator', 'BeautifulSoup']
 
 
-def get_soup(url: str, num_of_attempts: int = 3, delay: float = 1) -> BeautifulSoup or None:
+def get_soup(url: str, num_of_attempts: int = 3, delay: float = 1.) -> BeautifulSoup or None:
     if num_of_attempts == -1:
         return
     try:
@@ -36,6 +36,7 @@ def _get_context() -> ssl.SSLContext:
 
 def parser_decorator(url: str):
     def dec(func):
+
         def wrapper(*args, **kwargs):
             soup = get_soup(url, *args, **kwargs)
             if soup:
@@ -44,18 +45,10 @@ def parser_decorator(url: str):
                 logger.error(f'Parser returned NoneType object.')
                 return
 
+        setattr(wrapper, 'url', url)
         return wrapper
 
     return dec
 
 
-@parser_decorator('https://www.wg-gesucht.de/wohnungen-in-Tuebingen'
-                  '.127.2.1.0.html?offer_filter=1&sort_column=0&noDeact'
-                  '=1&city_id=127&category=2&rent_type=0&sMin=30&rMax=1500')
-def _parse_wg(soup: BeautifulSoup) -> str:
-    return soup.find_all('div', {'class': 'card_body'})[1].find('h3').find('a').text.strip()
-
-
-PARSER_DICT: Dict[str, Callable] = {
-    'WG': _parse_wg
-}
+PARSER_DICT: Dict[str, Callable] = {}
